/*
 * kgraft_patch_bsc1176931
 *
 * Fix for CVE-2020-0429, bsc#1176931
 *
 *  Upstream commits:
 *  4ac36a4adaf8 ("l2tp: Correctly return -EBADF from pppol2tp_getname.")
 *  61b9a047729b ("l2tp: fix race in l2tp_recv_common()")
 *  57377d635478 ("l2tp: ensure session can't get removed during
 *                 pppol2tp_session_ioctl()")
 *  dbdbc73b4478 ("l2tp: fix duplicate session creation")
 *  54c151d9ed13 ("l2tp: Refactor the codes with existing macros instead of
 *                 literal number")
 *  cdd10c962749 ("l2tp: ensure sessions are freed after their PPPOL2TP socket")
 *  b228a9406640 ("l2tp: fix race between l2tp_session_delete() and
 *                 l2tp_tunnel_closeall()")
 *
 *  SLE12-SP2 and -SP3 commits:
 *  none yet except for
 *  700c88e3399b3c37c543bacc8a84a40d2b9aae70
 *
 *  SLE12-SP4, SLE12-SP5, SLE15 and SLE15-SP1 commits:
 *  6c1d4b6729de4e3a2a8d85ae57e93d2f9489ee81
 *  ff8727069b144f702054a26f88576ffc6d4d5f6a
 *
 *  SLE15-SP2 commit:
 *  not affected
 *
 *
 *  Copyright (c) 2020 SUSE
 *  Author: Nicolai Stange <nstange@suse.de>
 *
 *  Based on the original Linux kernel code. Other copyrights apply.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#include <linux/kernel.h>
#include <linux/module.h>
#include "kgr_patch_bsc1176931.h"

int kgr_patch_bsc1176931_init(void)
{
	int ret;

	ret = kgr_patch_bsc1176931_core_init();
	if (ret)
		return ret;

	ret = kgr_patch_bsc1176931_ppp_init();
	if (ret) {
		kgr_patch_bsc1176931_core_cleanup();
		return ret;
	}

	ret = kgr_patch_bsc1176931_eth_init();
	if (ret) {
		kgr_patch_bsc1176931_ppp_cleanup();
		kgr_patch_bsc1176931_core_cleanup();
		return ret;
	}

	return 0;
}

void kgr_patch_bsc1176931_cleanup(void)
{
	kgr_patch_bsc1176931_eth_cleanup();
	kgr_patch_bsc1176931_ppp_cleanup();
	kgr_patch_bsc1176931_core_cleanup();
}
